<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS language="ca" version="2.1">
<context>
    <name>AboutDlg</name>
    <message>
        <source>About</source>
        <translation>Quant a</translation>
    </message>
</context>
<context>
    <name>AddNewTorrentDialog</name>
    <message>
        <source>Category:</source>
        <translation>Categoria:</translation>
    </message>
    <message>
        <source>Start torrent</source>
        <translation>Inicia el torrent</translation>
    </message>
    <message>
        <source>Skip hash check</source>
        <translation>Omet la comprovació del resum (hash)</translation>
    </message>
    <message>
        <source>Create subfolder</source>
        <translation>Crea una subcarpeta</translation>
    </message>
    <message>
        <source>Torrent Management Mode:</source>
        <translation>Mode de gestió de torrents:</translation>
    </message>
</context>
<context>
    <name>CategoryFilterModel</name>
    <message>
        <source>All</source>
        <translation>Totes</translation>
    </message>
    <message>
        <source>Uncategorized</source>
        <translation>Sense categoria</translation>
    </message>
</context>
<context>
    <name>CategoryFilterWidget</name>
    <message>
        <source>Add category...</source>
        <translation>Afegeix una categoria...</translation>
    </message>
    <message>
        <source>Remove category</source>
        <translation>Suprimeix la categoria</translation>
    </message>
    <message>
        <source>Remove unused categories</source>
        <translation>Suprimeix les categories no utilitzades</translation>
    </message>
    <message>
        <source>Resume torrents</source>
        <translation>Reprèn els torrents</translation>
    </message>
    <message>
        <source>Pause torrents</source>
        <translation>Pausa els torrents</translation>
    </message>
    <message>
        <source>Delete torrents</source>
        <translation>Suprimeix els torrents</translation>
    </message>
    <message>
        <source>New Category</source>
        <translation>Categoria nova</translation>
    </message>
    <message>
        <source>Edit category...</source>
        <translation>Edita la categoria...</translation>
    </message>
</context>
<context>
    <name>HttpServer</name>
    <message>
        <source>Exit qBittorrent</source>
        <translation>Surt del qBittorrent</translation>
    </message>
    <message>
        <source>Only one link per line</source>
        <translation>Només un enllaç per línia</translation>
    </message>
    <message>
        <source>Global upload rate limit must be greater than 0 or disabled.</source>
        <translation>El límit de pujada ha de ser major que 0 o estar inhabilitat.</translation>
    </message>
    <message>
        <source>Global download rate limit must be greater than 0 or disabled.</source>
        <translation>El límit de baixada ha de ser major que 0 o estar inhabilitat.</translation>
    </message>
    <message>
        <source>Alternative upload rate limit must be greater than 0 or disabled.</source>
        <translation>El límit de pujada alternatiu ha de ser major que 0 o estar inhabilitat.</translation>
    </message>
    <message>
        <source>Alternative download rate limit must be greater than 0 or disabled.</source>
        <translation>El límit de baixada alternativa ha de ser major que 0 o estar inhabilitat.</translation>
    </message>
    <message>
        <source>Maximum active downloads must be greater than -1.</source>
        <translation>El màxim de baixades actives ha de ser major de -1.</translation>
    </message>
    <message>
        <source>Maximum active uploads must be greater than -1.</source>
        <translation>El màxim de pujades actives ha de ser major de -1.</translation>
    </message>
    <message>
        <source>Maximum active torrents must be greater than -1.</source>
        <translation>El màxim de torrents actius ha de ser major de -1.</translation>
    </message>
    <message>
        <source>Maximum number of connections limit must be greater than 0 or disabled.</source>
        <translation>El nombre màxim del limiti de connexions ha de ser major que 0 o estar inhabilitat.</translation>
    </message>
    <message>
        <source>Maximum number of connections per torrent limit must be greater than 0 or disabled.</source>
        <translation>El nombre màxim del limit de connexions per torrent ha de ser major que 0 o estar inhabilitat.</translation>
    </message>
    <message>
        <source>Maximum number of upload slots per torrent limit must be greater than 0 or disabled.</source>
        <translation>El nombre màxim de pujades de ranures per torrent ha de ser major que 0 o estar inhabilitat.</translation>
    </message>
    <message>
        <source>Unable to save program preferences, qBittorrent is probably unreachable.</source>
        <translation>No es poden desar les preferències del programa, probablement el qBittorrent no és accessible.</translation>
    </message>
    <message>
        <source>IRC: #qbittorrent on Freenode</source>
        <translation>IRC: #qbittorrent a Freenode</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Desconegut</translation>
    </message>
    <message>
        <source>Share ratio limit must be between 0 and 9998.</source>
        <translation>El límit de la ràtio de compartició ha de ser entre 0 i 9998.</translation>
    </message>
    <message>
        <source>Seeding time limit must be between 0 and 525600 minutes.</source>
        <translation>El límit de la sembra ha de ser entre 0 i 525600 minuts.</translation>
    </message>
    <message>
        <source>The port used for incoming connections must be between 1 and 65535.</source>
        <translation>El port utilitzat per a connexions entrants ha de ser major de 1024 i menor de 65535.</translation>
    </message>
    <message>
        <source>The port used for the Web UI must be between 1 and 65535.</source>
        <translation>El port utilitzat per a la interfície d'usuari web ha de ser major de 1024 i menor de 65535.</translation>
    </message>
    <message>
        <source>Unable to log in, qBittorrent is probably unreachable.</source>
        <translation>No ha estat possible iniciar sessió, el qBittorrent deu estar il·localitzable en aquests moments. </translation>
    </message>
    <message>
        <source>Invalid Username or Password.</source>
        <translation>Nom d'usuari o contrasenya incorrectes.</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nom d'usuari</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Contrasenya</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Inicia sessió</translation>
    </message>
    <message>
        <source>Original authors</source>
        <translation>Autors originals</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Aplica</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Afegeix</translation>
    </message>
    <message>
        <source>Upload Torrents</source>
        <comment>Upload torrent files to qBittorent using WebUI</comment>
        <translation>Puja torrents</translation>
    </message>
    <message>
        <source>Save files to location:</source>
        <translation>Desa els fitxers a la ubicació:</translation>
    </message>
    <message>
        <source>Cookie:</source>
        <translation>Cookie:</translation>
    </message>
    <message>
        <source>Type folder here</source>
        <translation>Escriviu la carpeta aquí</translation>
    </message>
    <message>
        <source>More information</source>
        <translation>Més informació</translation>
    </message>
    <message>
        <source>Information about certificates</source>
        <translation>Informació sobre certificats</translation>
    </message>
    <message>
        <source>Set location</source>
        <translation>Estableix la ubicació</translation>
    </message>
    <message>
        <source>Limit upload rate</source>
        <translation>Limita la velocitat de pujada</translation>
    </message>
    <message>
        <source>Limit download rate</source>
        <translation>Limita la velocitat de baixada</translation>
    </message>
    <message>
        <source>Rename torrent</source>
        <translation>Canvia de nom el torrent</translation>
    </message>
    <message>
        <source>Other...</source>
        <comment>Save Files to: Watch Folder / Default Folder / Other...</comment>
        <translation>Altres ...</translation>
    </message>
    <message>
        <source>Monday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Dilluns</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Dimarts</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Dimecres</translation>
    </message>
    <message>
        <source>Thursday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Dijous</translation>
    </message>
    <message>
        <source>Friday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Divendres</translation>
    </message>
    <message>
        <source>Saturday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Dissabte</translation>
    </message>
    <message>
        <source>Sunday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Diumenge</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Tanca la sessió</translation>
    </message>
    <message>
        <source>Download Torrents from their URLs or Magnet links</source>
        <translation>Baixa torrents des dels URL o enllaços magnètics</translation>
    </message>
    <message>
        <source>Upload local torrent</source>
        <translation>Puja torrent locals</translation>
    </message>
    <message>
        <source>Are you sure you want to delete the selected torrents from the transfer list?</source>
        <translation>Esteu segur que voleu suprimir els torrent seleccionats de la llista de transferències?</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Desa</translation>
    </message>
    <message>
        <source>qBittorrent client is not reachable</source>
        <translation>El client qBittorrent no és accessible</translation>
    </message>
    <message>
        <source>Global number of upload slots limit must be greater than 0 or disabled.</source>
        <translation>El nombre global del límit de ranures de pujada ha de ser superior a 0 o inhabilitat.</translation>
    </message>
    <message>
        <source>Invalid category name:\nPlease do not use any special characters in the category name.</source>
        <translation>Nom de categoria no vàlid:
Si us plau, no useu cap caràcter especial al nom de la categoria.</translation>
    </message>
    <message>
        <source>Unable to create category</source>
        <translation>No es pot crear la categoria</translation>
    </message>
    <message>
        <source>Upload rate threshold must be greater than 0.</source>
        <translation>El llindar de la velocitat de pujada ha de ser superior a 0.</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Edita</translation>
    </message>
    <message>
        <source>Free space: %1</source>
        <translation>Espai lliure: %1</translation>
    </message>
    <message>
        <source>Torrent inactivity timer must be greater than 0.</source>
        <translation>El temporitzador d'inactivitat dels torrents ha de ser superior a 0.</translation>
    </message>
    <message>
        <source>Saving Management</source>
        <translation>Gestió de l'acció de desar</translation>
    </message>
    <message>
        <source>Download rate threshold must be greater than 0.</source>
        <translation>El llindar de la velocitat de baixada ha de ser superior a 0.</translation>
    </message>
    <message>
        <source>qBittorrent has been shutdown</source>
        <translation>El qBittorrent s'ha tancat.</translation>
    </message>
    <message>
        <source>JavaScript Required! You must enable JavaScript for the Web UI to work properly</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Edit</source>
        <translation>Edita</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Eines</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Fitxer</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Visualitza</translation>
    </message>
    <message>
        <source>Options...</source>
        <translation>Opcions...</translation>
    </message>
    <message>
        <source>Resume</source>
        <translation>Reprèn</translation>
    </message>
    <message>
        <source>Minimum Priority</source>
        <translation>Prioritat mínima</translation>
    </message>
    <message>
        <source>Top Priority</source>
        <translation>Prioritat màxima</translation>
    </message>
    <message>
        <source>Decrease Priority</source>
        <translation>Disminueix-ne la prioritat</translation>
    </message>
    <message>
        <source>Increase Priority</source>
        <translation>Incrementa'n la prioritat</translation>
    </message>
    <message>
        <source>Top Toolbar</source>
        <translation>Barra d'eines superior</translation>
    </message>
    <message>
        <source>Status Bar</source>
        <translation>Barra d'estat</translation>
    </message>
    <message>
        <source>Speed in Title Bar</source>
        <translation>Mostra velocitat a la barra de títol</translation>
    </message>
    <message>
        <source>Donate!</source>
        <translation>Feu una donació!</translation>
    </message>
    <message>
        <source>Resume All</source>
        <translation>Reprèn-ho tot</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Estadístiques</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Quant a</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Suprimeix</translation>
    </message>
    <message>
        <source>Pause All</source>
        <translation>Pausa-ho tot</translation>
    </message>
    <message>
        <source>Add Torrent File...</source>
        <translation>Afegeix un fitxer de torrent...</translation>
    </message>
    <message>
        <source>Documentation</source>
        <translation>Documentació</translation>
    </message>
    <message>
        <source>Add Torrent Link...</source>
        <translation>Afegeix un enllaç de torrent...</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Sí</translation>
    </message>
    <message>
        <source>No</source>
        <translation>No</translation>
    </message>
    <message>
        <source>Global Upload Speed Limit</source>
        <translation>Velocitat límit global de pujada</translation>
    </message>
    <message>
        <source>Global Download Speed Limit</source>
        <translation>Velocitat límit global de baixada</translation>
    </message>
    <message>
        <source>Are you sure you want to quit qBittorrent?</source>
        <translation>Segur que voleu sortir del qBittorrent?</translation>
    </message>
    <message>
        <source>[D: %1, U: %2] qBittorrent %3</source>
        <comment>D = Download; U = Upload; %3 is qBittorrent version</comment>
        <translation>[B: %1, P: %2] qBittorrent %3</translation>
    </message>
    <message>
        <source>Alternative speed limits</source>
        <translation>Límits de velocitat alternatius</translation>
    </message>
    <message>
        <source>Search Engine</source>
        <translation>Motor de cerca</translation>
    </message>
    <message>
        <source>Filter torrent list...</source>
        <translation>Filtra la llista de torrents...</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Cerca</translation>
    </message>
    <message>
        <source>Transfers</source>
        <translation>Transferències</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Opcions</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Baixades</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Connexió</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Velocitat</translation>
    </message>
    <message>
        <source>BitTorrent</source>
        <translation>Bittorrent</translation>
    </message>
    <message>
        <source>Web UI</source>
        <translation>Interfície web</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Llengua</translation>
    </message>
    <message>
        <source>User Interface Language:</source>
        <translation>Llengua de la interfície d'usuari:</translation>
    </message>
    <message>
        <source>Email notification upon download completion</source>
        <translation>Notificació per correu electrònic de l'acabament de les descàrregues</translation>
    </message>
    <message>
        <source>Run external program on torrent completion</source>
        <translation>Executa un programa extern en acabar el torrent.</translation>
    </message>
    <message>
        <source>IP Filtering</source>
        <translation>Filtratge d'IP</translation>
    </message>
    <message>
        <source>Schedule the use of alternative rate limits</source>
        <translation>Programació de l'ús de límits de ràtio alternatius</translation>
    </message>
    <message>
        <source>Torrent Queueing</source>
        <translation>Cua de torrents</translation>
    </message>
    <message>
        <source>Seed torrents until their seeding time reaches</source>
        <translation>Sembra torrents fins que s'esgoti el seu temps de sembra.</translation>
    </message>
    <message>
        <source>Automatically add these trackers to new downloads:</source>
        <translation>Afegeix automàticament aquests rastrejadors a les baixades noves:</translation>
    </message>
    <message>
        <source>Web User Interface (Remote control)</source>
        <translation>Interfície d'usuari web (control remot)</translation>
    </message>
    <message>
        <source>IP address:</source>
        <translation>Adreça IP:</translation>
    </message>
    <message>
        <source>Server domains:</source>
        <translation>Dominis de servidor:</translation>
    </message>
    <message>
        <source>Use HTTPS instead of HTTP</source>
        <translation>Usa HTTPS en lloc d'HTTP</translation>
    </message>
    <message>
        <source>Bypass authentication for clients on localhost</source>
        <translation>Evita l'autenticació per als clients en l'amfitrió local</translation>
    </message>
    <message>
        <source>Bypass authentication for clients in whitelisted IP subnets</source>
        <translation>Evita l'autenticació per als clients en subxarxes en la llista blanca</translation>
    </message>
    <message>
        <source>Update my dynamic domain name</source>
        <translation>Actualitza el meu nom de domini dinàmic</translation>
    </message>
    <message>
        <source>Keep incomplete torrents in:</source>
        <translation>Manté els torrents incomplets a:</translation>
    </message>
    <message>
        <source>Copy .torrent files to:</source>
        <translation>Copieu els fitxers torrent a:</translation>
    </message>
    <message>
        <source>Copy .torrent files for finished downloads to:</source>
        <translation>Copia els fitxers .torrent de les baixades acabades a:</translation>
    </message>
    <message>
        <source>Pre-allocate disk space for all files</source>
        <translation>Preassigna espai al disc per a tots els fitxers</translation>
    </message>
    <message>
        <source>Append .!qB extension to incomplete files</source>
        <translation>Afegeix l'extensió .!qB a fitxers incomplets</translation>
    </message>
    <message>
        <source>Automatically add torrents from:</source>
        <translation>Afegeix torrents automàticament des de:</translation>
    </message>
    <message>
        <source>SMTP server:</source>
        <translation>Servidor SMTP:</translation>
    </message>
    <message>
        <source>This server requires a secure connection (SSL)</source>
        <translation>El servidor requereix una connexió segura (SSL)</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Autentificació</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Nom d'usuari:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Contrasenya:</translation>
    </message>
    <message>
        <source>Enabled protocol:</source>
        <translation>Protocol habilitat:</translation>
    </message>
    <message>
        <source>TCP and μTP</source>
        <translation>TCP i μTP</translation>
    </message>
    <message>
        <source>Listening Port</source>
        <translation>Port d'escolta</translation>
    </message>
    <message>
        <source>Port used for incoming connections:</source>
        <translation>Port utilitzat per a connexions entrants:</translation>
    </message>
    <message>
        <source>Use UPnP / NAT-PMP port forwarding from my router</source>
        <translation>Utilitza UPnP / NAT-PMP reenviament de ports del router</translation>
    </message>
    <message>
        <source>Use different port on each startup</source>
        <translation>Usa un pot diferent a cada inici</translation>
    </message>
    <message>
        <source>Connections Limits</source>
        <translation>Límits de connexió</translation>
    </message>
    <message>
        <source>Maximum number of connections per torrent:</source>
        <translation>Nombre màxim de connexions per torrent:</translation>
    </message>
    <message>
        <source>Global maximum number of connections:</source>
        <translation>Nombre global màxim de connexions:</translation>
    </message>
    <message>
        <source>Maximum number of upload slots per torrent:</source>
        <translation>Nombre màxim de ranures de pujada per torrent:</translation>
    </message>
    <message>
        <source>Global maximum number of upload slots:</source>
        <translation>Nombre global màxim de ranures de pujada:</translation>
    </message>
    <message>
        <source>Proxy Server</source>
        <translation>Servidor intermediaria</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Tipus:</translation>
    </message>
    <message>
        <source>(None)</source>
        <translation>(Cap)</translation>
    </message>
    <message>
        <source>SOCKS4</source>
        <translation>SOCKS4</translation>
    </message>
    <message>
        <source>SOCKS5</source>
        <translation>SOCKS5</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Amfitrió:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Port:</translation>
    </message>
    <message>
        <source>Use proxy for peer connections</source>
        <translation>Usa un servidor intermediari per a connexions d'igual a igual</translation>
    </message>
    <message>
        <source>Disable connections not supported by proxies</source>
        <translation>Inhabilita les connexions no admeses per servidors intermediaris</translation>
    </message>
    <message>
        <source>Use proxy only for torrents</source>
        <translation>Utilitza el servidor intermediari només per als torrents</translation>
    </message>
    <message>
        <source>Filter path (.dat, .p2p, .p2b):</source>
        <translation>Camí del filtre (.dat, .p2p, .p2b):</translation>
    </message>
    <message>
        <source>Manually banned IP addresses...</source>
        <translation>Adreces IP prohibides manualment...</translation>
    </message>
    <message>
        <source>Apply to trackers</source>
        <translation>Aplica als rastrejadors</translation>
    </message>
    <message>
        <source>Global Rate Limits</source>
        <translation>Límits de velocitat globals</translation>
    </message>
    <message>
        <source>Upload:</source>
        <translation>Pujada:</translation>
    </message>
    <message>
        <source>Download:</source>
        <translation>Baixada:</translation>
    </message>
    <message>
        <source>Alternative Rate Limits</source>
        <translation>Límits de velocitat alternatius</translation>
    </message>
    <message>
        <source>From:</source>
        <extracomment>from (time1 to time2)</extracomment>
        <translation>Des de:</translation>
    </message>
    <message>
        <source>To:</source>
        <extracomment>time1 to time2</extracomment>
        <translation>A:</translation>
    </message>
    <message>
        <source>When:</source>
        <translation>Quan:</translation>
    </message>
    <message>
        <source>Every day</source>
        <translation>Cada dia</translation>
    </message>
    <message>
        <source>Weekdays</source>
        <translation>De dilluns a divendres</translation>
    </message>
    <message>
        <source>Weekends</source>
        <translation>Caps de setmana</translation>
    </message>
    <message>
        <source>Rate Limits Settings</source>
        <translation>Paràmetres dels límits de velocitat</translation>
    </message>
    <message>
        <source>Apply rate limit to transport overhead</source>
        <translation>Aplica un límit de velocitat a la sobrecàrrega de transport</translation>
    </message>
    <message>
        <source>Apply rate limit to µTP protocol</source>
        <translation>Aplica un límit de velocitat al protocol µTP</translation>
    </message>
    <message>
        <source>Privacy</source>
        <translation>Privacitat</translation>
    </message>
    <message>
        <source>Enable DHT (decentralized network) to find more peers</source>
        <translation>Activa DHT (xarxa descentralitzada) per trobar més clients</translation>
    </message>
    <message>
        <source>Enable Peer Exchange (PeX) to find more peers</source>
        <translation>Habilita l'intercanvi de clients (PeX) per trobar-ne més </translation>
    </message>
    <message>
        <source>Enable Local Peer Discovery to find more peers</source>
        <translation>Habilita el descobriment de clients locals per trobar-ne més</translation>
    </message>
    <message>
        <source>Encryption mode:</source>
        <translation>Mode de xifratge:</translation>
    </message>
    <message>
        <source>Prefer encryption</source>
        <translation>Preferència de xifratge</translation>
    </message>
    <message>
        <source>Require encryption</source>
        <translation>Requereix xifratge</translation>
    </message>
    <message>
        <source>Disable encryption</source>
        <translation>Inhabilita el xifratge</translation>
    </message>
    <message>
        <source>Enable anonymous mode</source>
        <translation>Habilita el mode anònim</translation>
    </message>
    <message>
        <source>Maximum active downloads:</source>
        <translation>Màxim de baixades actives:</translation>
    </message>
    <message>
        <source>Maximum active uploads:</source>
        <translation>Màxim de pujades actives:</translation>
    </message>
    <message>
        <source>Maximum active torrents:</source>
        <translation>Màxim de torrent actius:</translation>
    </message>
    <message>
        <source>Do not count slow torrents in these limits</source>
        <translation>No comptis els torrents lents fora d'aquests límits</translation>
    </message>
    <message>
        <source>Share Ratio Limiting</source>
        <translation>Limitació de ràtio de compartició</translation>
    </message>
    <message>
        <source>Seed torrents until their ratio reaches</source>
        <translation>Sembra els torrents fins que la ràtio arribi a </translation>
    </message>
    <message>
        <source>then</source>
        <translation>després</translation>
    </message>
    <message>
        <source>Pause them</source>
        <translation>Pausa-ho</translation>
    </message>
    <message>
        <source>Remove them</source>
        <translation>Suprimeix-ho</translation>
    </message>
    <message>
        <source>Use UPnP / NAT-PMP to forward the port from my router</source>
        <translation>Utilitza UPnP / NAT-PMP per reenviar el port des de l'encaminador</translation>
    </message>
    <message>
        <source>Certificate:</source>
        <translation>Certificat:</translation>
    </message>
    <message>
        <source>Key:</source>
        <translation>Clau:</translation>
    </message>
    <message>
        <source>Register</source>
        <translation>Registre</translation>
    </message>
    <message>
        <source>Domain name:</source>
        <translation>Nom de domini:</translation>
    </message>
    <message>
        <source>Supported parameters (case sensitive):</source>
        <translation>Paràmetres admesos (sensible a majúscules):</translation>
    </message>
    <message>
        <source>%N: Torrent name</source>
        <translation>%N: nom del torrent</translation>
    </message>
    <message>
        <source>%L: Category</source>
        <translation>%L: categoria</translation>
    </message>
    <message>
        <source>%G: Tags (seperated by comma)</source>
        <translation>%G: Etiquetes (separades per comes)</translation>
    </message>
    <message>
        <source>%F: Content path (same as root path for multifile torrent)</source>
        <translation>%F: Camí del contingut (igual que el camí d'arrel per a torrents de fitxers múltiples)</translation>
    </message>
    <message>
        <source>%R: Root path (first torrent subdirectory path)</source>
        <translation>%R: camí d'arrel (camí del subdirectori del primer torrent)</translation>
    </message>
    <message>
        <source>%D: Save path</source>
        <translation>%D: camí per desar</translation>
    </message>
    <message>
        <source>%C: Number of files</source>
        <translation>%C: nombre de fitxers</translation>
    </message>
    <message>
        <source>%Z: Torrent size (bytes)</source>
        <translation>%Z mida del torrent (bytes)</translation>
    </message>
    <message>
        <source>%T: Current tracker</source>
        <translation>%T: rastrejador actual</translation>
    </message>
    <message>
        <source>%I: Info hash</source>
        <translation>%I: informació del resum</translation>
    </message>
    <message>
        <source>Tip: Encapsulate parameter with quotation marks to avoid text being cut off at whitespace (e.g., "%N")</source>
        <translation>Tip: emmarqueu el paràmetre amb cometes per evitar que el text es talli a l'espai en blanc (p.e., "%N")</translation>
    </message>
    <message>
        <source>The Web UI username must be at least 3 characters long.</source>
        <translation>El nom  d'usuari de la interfície web ha de tenir almenys 3 caràcters.</translation>
    </message>
    <message>
        <source>The Web UI password must be at least 6 characters long.</source>
        <translation>La contrasenya de la interfície web ha de tenir almenys 6 caràcters.</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minuts</translation>
    </message>
    <message>
        <source>KiB/s</source>
        <translation>KiB/s</translation>
    </message>
    <message>
        <source>Enable clickjacking protection</source>
        <translation>Habilita la protecció contra segrest de clic</translation>
    </message>
    <message>
        <source>Enable Cross-Site Request Forgery (CSRF) protection</source>
        <translation>Habilita la protecció contra la falsificació de peticions de llocs creuats (CSRF).</translation>
    </message>
    <message>
        <source>Delete .torrent files afterwards</source>
        <translation>Suprimeix els fitxers .torrent després</translation>
    </message>
    <message>
        <source>Download rate threshold:</source>
        <translation>Llindar de la velocitat de baixada:</translation>
    </message>
    <message>
        <source>Upload rate threshold:</source>
        <translation>Llindar de la velocitat de pujada:</translation>
    </message>
    <message>
        <source>Change current password</source>
        <translation>Canvia la contrasenya actual</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Automàtic</translation>
    </message>
    <message>
        <source>Use alternative Web UI</source>
        <translation>Usa la interfície web alternativa</translation>
    </message>
    <message>
        <source>Default Save Path:</source>
        <translation>Camí per desar per defecte:</translation>
    </message>
    <message>
        <source>The alternative Web UI files location cannot be blank.</source>
        <translation>La ubicació alternativa dels fitxers de la interfície web no pot estar en blanc.</translation>
    </message>
    <message>
        <source>Do not start the download automatically</source>
        <translation>No iniciïs la baixada automàticament</translation>
    </message>
    <message>
        <source>Switch torrent to Manual Mode</source>
        <translation>Canvia el torrent al mode manual</translation>
    </message>
    <message>
        <source>When Torrent Category changed:</source>
        <translation>En canviar la categoria del torrent:</translation>
    </message>
    <message>
        <source>Relocate affected torrents</source>
        <translation>Reubica els torrents afectats</translation>
    </message>
    <message>
        <source>Apply rate limit to peers on LAN</source>
        <translation>Aplica el límit de velocitat als clients amb LAN</translation>
    </message>
    <message>
        <source>0 means unlimited</source>
        <translation>0 significa 'sense límit'</translation>
    </message>
    <message>
        <source>Relocate torrent</source>
        <translation>Reubica el torrent</translation>
    </message>
    <message>
        <source>When Default Save Path changed:</source>
        <translation>En canviar el camí per desar per defecte:</translation>
    </message>
    <message>
        <source>Enable Host header validation</source>
        <translation>Habilita la validació de la capçalera de l'amfitrió</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Seguretat</translation>
    </message>
    <message>
        <source>When Category Save Path changed:</source>
        <translation>En canviar la categoria del camí per desar:</translation>
    </message>
    <message>
        <source>Create subfolder for torrents with multiple files</source>
        <translation>Crea una subcarpeta per als torrents amb fitxers múltiples.</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>segons</translation>
    </message>
    <message>
        <source>Switch affected torrents to Manual Mode</source>
        <translation>Canvia els torrents afectats al mode manual</translation>
    </message>
    <message>
        <source>Files location:</source>
        <translation>Ubicació dels fitxers:</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <source>Torrent inactivity timer:</source>
        <translation>Temporitzador d'inactivitat del torrent:</translation>
    </message>
    <message>
        <source>Default Torrent Management Mode:</source>
        <translation>Mode de gestió dels torrents per defecte:</translation>
    </message>
    <message>
        <source>When adding a torrent</source>
        <translation>En afegir un torrent</translation>
    </message>
</context>
<context>
    <name>PeerListWidget</name>
    <message>
        <source>IP</source>
        <translation>IP</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Flags</source>
        <translation>Banderes</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Connexió</translation>
    </message>
    <message>
        <source>Client</source>
        <comment>i.e.: Client application</comment>
        <translation>Client</translation>
    </message>
    <message>
        <source>Progress</source>
        <comment>i.e: % downloaded</comment>
        <translation>Progrés</translation>
    </message>
    <message>
        <source>Down Speed</source>
        <comment>i.e: Download speed</comment>
        <translation>Vel. de baixada</translation>
    </message>
    <message>
        <source>Up Speed</source>
        <comment>i.e: Upload speed</comment>
        <translation>Velocitat de pujada</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <comment>i.e: total data downloaded</comment>
        <translation>Baixat</translation>
    </message>
    <message>
        <source>Uploaded</source>
        <comment>i.e: total data uploaded</comment>
        <translation>Pujat</translation>
    </message>
    <message>
        <source>Relevance</source>
        <comment>i.e: How relevant this peer is to us. How many pieces it has that we don't.</comment>
        <translation>Rellevància</translation>
    </message>
    <message>
        <source>Files</source>
        <comment>i.e. files that are being downloaded right now</comment>
        <translation>Fitxers</translation>
    </message>
    <message>
        <source>Country</source>
        <translation>País</translation>
    </message>
</context>
<context>
    <name>PropListDelegate</name>
    <message>
        <source>Normal</source>
        <comment>Normal (priority)</comment>
        <translation>Normal</translation>
    </message>
    <message>
        <source>High</source>
        <comment>High (priority)</comment>
        <translation>Alt</translation>
    </message>
    <message>
        <source>Maximum</source>
        <comment>Maximum (priority)</comment>
        <translation>Màxim</translation>
    </message>
</context>
<context>
    <name>PropTabBar</name>
    <message>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <source>Trackers</source>
        <translation>Rastrejadors</translation>
    </message>
    <message>
        <source>Peers</source>
        <translation>Clients</translation>
    </message>
    <message>
        <source>HTTP Sources</source>
        <translation>Fonts HTTP</translation>
    </message>
    <message>
        <source>Content</source>
        <translation>Contingut</translation>
    </message>
</context>
<context>
    <name>PropertiesWidget</name>
    <message>
        <source>Downloaded:</source>
        <translation>Baixat:</translation>
    </message>
    <message>
        <source>Transfer</source>
        <translation>Transferència</translation>
    </message>
    <message>
        <source>Time Active:</source>
        <extracomment>Time (duration) the torrent is active (not paused)</extracomment>
        <translation>Temps actiu:</translation>
    </message>
    <message>
        <source>ETA:</source>
        <translation>Temps estimat:</translation>
    </message>
    <message>
        <source>Uploaded:</source>
        <translation>Pujada:</translation>
    </message>
    <message>
        <source>Seeds:</source>
        <translation>Llavors:</translation>
    </message>
    <message>
        <source>Download Speed:</source>
        <translation>Velocitat de baixada:</translation>
    </message>
    <message>
        <source>Upload Speed:</source>
        <translation>Velocitat de pujada:</translation>
    </message>
    <message>
        <source>Peers:</source>
        <translation>Clients:</translation>
    </message>
    <message>
        <source>Download Limit:</source>
        <translation>Límit de baixada:</translation>
    </message>
    <message>
        <source>Upload Limit:</source>
        <translation>Límit de pujada:</translation>
    </message>
    <message>
        <source>Wasted:</source>
        <translation>Perdut:</translation>
    </message>
    <message>
        <source>Connections:</source>
        <translation>Connexions:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informació</translation>
    </message>
    <message>
        <source>Comment:</source>
        <translation>Comentari:</translation>
    </message>
    <message>
        <source>Share Ratio:</source>
        <translation>Ràtio de compartició:</translation>
    </message>
    <message>
        <source>Reannounce In:</source>
        <translation>Reanuncia:</translation>
    </message>
    <message>
        <source>Last Seen Complete:</source>
        <translation>Últim cop vist complet:</translation>
    </message>
    <message>
        <source>Total Size:</source>
        <translation>Mida total:</translation>
    </message>
    <message>
        <source>Pieces:</source>
        <translation>Trossos:</translation>
    </message>
    <message>
        <source>Created By:</source>
        <translation>Creat per:</translation>
    </message>
    <message>
        <source>Added On:</source>
        <translation>Afegit el:</translation>
    </message>
    <message>
        <source>Completed On:</source>
        <translation>Completat el:</translation>
    </message>
    <message>
        <source>Created On:</source>
        <translation>Creat el:</translation>
    </message>
    <message>
        <source>Torrent Hash:</source>
        <translation>Resum del torrent (hash):</translation>
    </message>
    <message>
        <source>Save Path:</source>
        <translation>Camí per desar:</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Mai</translation>
    </message>
    <message>
        <source>%1 x %2 (have %3)</source>
        <comment>(torrent pieces) eg 152 x 4MB (have 25)</comment>
        <translation>%1 x %2 (té %3)</translation>
    </message>
    <message>
        <source>%1 (%2 this session)</source>
        <translation>%1 (%2 en aquesta sessió)</translation>
    </message>
    <message>
        <source>%1 (%2 max)</source>
        <comment>%1 and %2 are numbers, e.g. 3 (10 max)</comment>
        <translation>%1 (%2 màxim)</translation>
    </message>
    <message>
        <source>%1 (%2 total)</source>
        <comment>%1 and %2 are numbers, e.g. 3 (10 total)</comment>
        <translation>%1 (%2 total)</translation>
    </message>
    <message>
        <source>%1 (%2 avg.)</source>
        <comment>%1 and %2 are speed rates, e.g. 200KiB/s (100KiB/s avg.)</comment>
        <translation>%1 (%2 de mitjana)</translation>
    </message>
    <message>
        <source>Download limit:</source>
        <translation>Límit de baixada:</translation>
    </message>
    <message>
        <source>Upload limit:</source>
        <translation>Límit de pujada:</translation>
    </message>
</context>
<context>
    <name>ScanFoldersModel</name>
    <message>
        <source>Monitored Folder</source>
        <translation>Carpeta monitorada</translation>
    </message>
    <message>
        <source>Override Save Location</source>
        <translation>Salta't la ubicació per desar</translation>
    </message>
    <message>
        <source>Monitored folder</source>
        <translation>Carpeta monitorada</translation>
    </message>
    <message>
        <source>Default save location</source>
        <translation>Ubicació per desar per defecte</translation>
    </message>
</context>
<context>
    <name>SpeedLimitDialog</name>
    <message>
        <source>KiB/s</source>
        <translation>KiB/s</translation>
    </message>
</context>
<context>
    <name>StatsDialog</name>
    <message>
        <source>Statistics</source>
        <translation>Estadístiques</translation>
    </message>
    <message>
        <source>User statistics</source>
        <translation>Estadístiques d'usuari</translation>
    </message>
    <message>
        <source>Cache statistics</source>
        <translation>Estadístiques de memòria cau</translation>
    </message>
    <message>
        <source>Read cache hits:</source>
        <translation>Resultats de lectura de la memòria cau:</translation>
    </message>
    <message>
        <source>Average time in queue:</source>
        <translation>Mitjana de temps a la cua:</translation>
    </message>
    <message>
        <source>Connected peers:</source>
        <translation>Clients connectats:</translation>
    </message>
    <message>
        <source>All-time share ratio:</source>
        <translation>Ràtio de compartició de sempre:</translation>
    </message>
    <message>
        <source>All-time download:</source>
        <translation>Baixada de sempre:</translation>
    </message>
    <message>
        <source>Session waste:</source>
        <translation>Sessió malgastada:</translation>
    </message>
    <message>
        <source>All-time upload:</source>
        <translation>Pujada de sempre:</translation>
    </message>
    <message>
        <source>Total buffer size:</source>
        <translation>Mida total de la memòria intermèdia:</translation>
    </message>
    <message>
        <source>Performance statistics</source>
        <translation>Estadístiques de rendiment</translation>
    </message>
    <message>
        <source>Queued I/O jobs:</source>
        <translation>Ordres d'entrada / sortida a la cua:</translation>
    </message>
    <message>
        <source>Write cache overload:</source>
        <translation>Escriure memòria cau sobrecarregada:</translation>
    </message>
    <message>
        <source>Read cache overload:</source>
        <translation>Llegir memòria cau sobrecarregada:</translation>
    </message>
    <message>
        <source>Total queued size:</source>
        <translation>Mida total a la cua:</translation>
    </message>
</context>
<context>
    <name>StatusBar</name>
    <message>
        <source>DHT: %1 nodes</source>
        <translation>DHT: %1 nodes</translation>
    </message>
</context>
<context>
    <name>StatusFilterWidget</name>
    <message>
        <source>All (0)</source>
        <comment>this is for the status filter</comment>
        <translation>Tots (0)</translation>
    </message>
    <message>
        <source>Downloading (0)</source>
        <translation>Baixant (0)</translation>
    </message>
    <message>
        <source>Seeding (0)</source>
        <translation>Sembrant (0)</translation>
    </message>
    <message>
        <source>Completed (0)</source>
        <translation>Completats (0)</translation>
    </message>
    <message>
        <source>Resumed (0)</source>
        <translation>Represos (0)</translation>
    </message>
    <message>
        <source>Paused (0)</source>
        <translation>Pausats (0)</translation>
    </message>
    <message>
        <source>Active (0)</source>
        <translation>Actius (0)</translation>
    </message>
    <message>
        <source>Inactive (0)</source>
        <translation>Inactius (0)</translation>
    </message>
    <message>
        <source>Errored (0)</source>
        <translation>Amb errors (0)</translation>
    </message>
    <message>
        <source>All (%1)</source>
        <translation>Tots (%1)</translation>
    </message>
    <message>
        <source>Downloading (%1)</source>
        <translation>Baixant (%1)</translation>
    </message>
    <message>
        <source>Seeding (%1)</source>
        <translation>Sembrant (%1)</translation>
    </message>
    <message>
        <source>Completed (%1)</source>
        <translation>Completats (%1)</translation>
    </message>
    <message>
        <source>Paused (%1)</source>
        <translation>Pausats (%1)</translation>
    </message>
    <message>
        <source>Resumed (%1)</source>
        <translation>Represos (%1)</translation>
    </message>
    <message>
        <source>Active (%1)</source>
        <translation>Actius (%1)</translation>
    </message>
    <message>
        <source>Inactive (%1)</source>
        <translation>Inactius (%1)</translation>
    </message>
    <message>
        <source>Errored (%1)</source>
        <translation>Amb errors (%1)</translation>
    </message>
</context>
<context>
    <name>TorrentContentModel</name>
    <message>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Mida</translation>
    </message>
    <message>
        <source>Progress</source>
        <translation>Progrés</translation>
    </message>
    <message>
        <source>Download Priority</source>
        <translation>Prioritat de baixada</translation>
    </message>
    <message>
        <source>Remaining</source>
        <translation>Restant</translation>
    </message>
    <message>
        <source>Availability</source>
        <translation>Disponibilitat</translation>
    </message>
</context>
<context>
    <name>TransferListModel</name>
    <message>
        <source>Name</source>
        <comment>i.e: torrent name</comment>
        <translation>Nom</translation>
    </message>
    <message>
        <source>Size</source>
        <comment>i.e: torrent size</comment>
        <translation>Mida</translation>
    </message>
    <message>
        <source>Done</source>
        <comment>% Done</comment>
        <translation>Fet</translation>
    </message>
    <message>
        <source>Status</source>
        <comment>Torrent status (e.g. downloading, seeding, paused)</comment>
        <translation>Estat</translation>
    </message>
    <message>
        <source>Seeds</source>
        <comment>i.e. full sources (often untranslated)</comment>
        <translation>Llavors</translation>
    </message>
    <message>
        <source>Peers</source>
        <comment>i.e. partial sources (often untranslated)</comment>
        <translation>Clients</translation>
    </message>
    <message>
        <source>Down Speed</source>
        <comment>i.e: Download speed</comment>
        <translation>Vel. de baixada</translation>
    </message>
    <message>
        <source>Up Speed</source>
        <comment>i.e: Upload speed</comment>
        <translation>Vel. de pujada</translation>
    </message>
    <message>
        <source>Ratio</source>
        <comment>Share ratio</comment>
        <translation>Ràtio</translation>
    </message>
    <message>
        <source>ETA</source>
        <comment>i.e: Estimated Time of Arrival / Time left</comment>
        <translation>Temps estimat</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Categoria</translation>
    </message>
    <message>
        <source>Tags</source>
        <translation>Etiquetes</translation>
    </message>
    <message>
        <source>Added On</source>
        <comment>Torrent was added to transfer list on 01/01/2010 08:00</comment>
        <translation>Afegit el</translation>
    </message>
    <message>
        <source>Completed On</source>
        <comment>Torrent was completed on 01/01/2010 08:00</comment>
        <translation>Completat a</translation>
    </message>
    <message>
        <source>Tracker</source>
        <translation>Rastrejador</translation>
    </message>
    <message>
        <source>Down Limit</source>
        <comment>i.e: Download limit</comment>
        <translation>Límit baixada</translation>
    </message>
    <message>
        <source>Up Limit</source>
        <comment>i.e: Upload limit</comment>
        <translation>Límit pujada</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <comment>Amount of data downloaded (e.g. in MB)</comment>
        <translation>Baixats</translation>
    </message>
    <message>
        <source>Uploaded</source>
        <comment>Amount of data uploaded (e.g. in MB)</comment>
        <translation>Pujats</translation>
    </message>
    <message>
        <source>Session Download</source>
        <comment>Amount of data downloaded since program open (e.g. in MB)</comment>
        <translation>Baixades durant la sessió</translation>
    </message>
    <message>
        <source>Session Upload</source>
        <comment>Amount of data uploaded since program open (e.g. in MB)</comment>
        <translation>Pujades durant la sessió</translation>
    </message>
    <message>
        <source>Remaining</source>
        <comment>Amount of data left to download (e.g. in MB)</comment>
        <translation>Restants</translation>
    </message>
    <message>
        <source>Time Active</source>
        <comment>Time (duration) the torrent is active (not paused)</comment>
        <translation>Temps actiu</translation>
    </message>
    <message>
        <source>Save path</source>
        <comment>Torrent save path</comment>
        <translation>Camí per desar</translation>
    </message>
    <message>
        <source>Completed</source>
        <comment>Amount of data completed (e.g. in MB)</comment>
        <translation>Completat</translation>
    </message>
    <message>
        <source>Ratio Limit</source>
        <comment>Upload share ratio limit</comment>
        <translation>Límit de ràtio</translation>
    </message>
    <message>
        <source>Last Seen Complete</source>
        <comment>Indicates the time when the torrent was last seen complete/whole</comment>
        <translation>Últim cop vist complet</translation>
    </message>
    <message>
        <source>Last Activity</source>
        <comment>Time passed since a chunk was downloaded/uploaded</comment>
        <translation>Darrera activitat</translation>
    </message>
    <message>
        <source>Total Size</source>
        <comment>i.e. Size including unwanted data</comment>
        <translation>Mida total</translation>
    </message>
</context>
<context>
    <name>TrackerListWidget</name>
    <message>
        <source>URL</source>
        <translation>URL</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Estat</translation>
    </message>
    <message>
        <source>Peers</source>
        <translation>Clients</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Missatge</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <translation>Baixat</translation>
    </message>
    <message>
        <source>Tracker URL:</source>
        <translation>URL del rastrejador:</translation>
    </message>
    <message>
        <source>Updating...</source>
        <translation>Actualitzant...</translation>
    </message>
    <message>
        <source>Working</source>
        <translation>Operatiu</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Inhabilitat</translation>
    </message>
    <message>
        <source>Not contacted yet</source>
        <translation>Encara no s'hi ha contactat.</translation>
    </message>
    <message>
        <source>#</source>
        <translation>#</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>N / D</translation>
    </message>
    <message>
        <source>Seeds</source>
        <translation>Llavors</translation>
    </message>
    <message>
        <source>Not working</source>
        <translation>No funciona</translation>
    </message>
    <message>
        <source>Copy tracker URL</source>
        <translation>Copia l'URL del rastrejador</translation>
    </message>
    <message>
        <source>Add a new tracker...</source>
        <translation>Afegeix un rastrejador nou...</translation>
    </message>
    <message>
        <source>Edit tracker URL...</source>
        <translation>Edita l'URL del rastrejador...</translation>
    </message>
    <message>
        <source>Tracker editing</source>
        <translation>Edició del rastrejador</translation>
    </message>
    <message>
        <source>Leeches</source>
        <translation>Sangoneres</translation>
    </message>
    <message>
        <source>Remove tracker</source>
        <translation>Suprimeix el rastrejador</translation>
    </message>
</context>
<context>
    <name>TrackersAdditionDialog</name>
    <message>
        <source>Trackers addition dialog</source>
        <translation>Diàleg per a afegir rastrejadors</translation>
    </message>
    <message>
        <source>List of trackers to add (one per line):</source>
        <translation>Llista de rastrejadors a afegir (un per línia):</translation>
    </message>
</context>
<context>
    <name>TransferListDelegate</name>
    <message>
        <source>%1 ago</source>
        <comment>e.g.: 1h 20m ago</comment>
        <translation>fa %1</translation>
    </message>
    <message>
        <source>Allocating</source>
        <translation>Assignació</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>En pausa</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Completat</translation>
    </message>
    <message>
        <source>Moving</source>
        <translation>Moure</translation>
    </message>
    <message>
        <source>[F] Seeding</source>
        <translation>[F] Sembrant</translation>
    </message>
    <message>
        <source>Seeding</source>
        <translation>Sembrant</translation>
    </message>
    <message>
        <source>Queued</source>
        <translation>A la cua</translation>
    </message>
    <message>
        <source>Errored</source>
        <translation>Amb errors</translation>
    </message>
    <message>
        <source>[F] Downloading</source>
        <translation>[F] Baixant</translation>
    </message>
    <message>
        <source>Downloading metadata</source>
        <translation>Baixant metadades</translation>
    </message>
    <message>
        <source>Checking</source>
        <translation>Comprovant</translation>
    </message>
    <message>
        <source>Missing Files</source>
        <translation>Fitxers absents</translation>
    </message>
    <message>
        <source>Queued for checking</source>
        <translation>A la cua per comprovar</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation>Baixant</translation>
    </message>
    <message>
        <source>Checking resume data</source>
        <translation>Comprovant les dades de represa</translation>
    </message>
    <message>
        <source>Stalled</source>
        <translation>Calat</translation>
    </message>
</context>
<context>
    <name>TransferListFiltersWidget</name>
    <message>
        <source>Status</source>
        <translation>Estat</translation>
    </message>
    <message>
        <source>Categories</source>
        <translation>Categories</translation>
    </message>
</context>
<context>
    <name>TransferListWidget</name>
    <message>
        <source>Torrent Download Speed Limiting</source>
        <translation>Límit de velocitat de baixada de torrents</translation>
    </message>
    <message>
        <source>Torrent Upload Speed Limiting</source>
        <translation>Límit de velocitat de pujada de torrents</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Canvia el nom</translation>
    </message>
    <message>
        <source>Resume</source>
        <comment>Resume/start the torrent</comment>
        <translation>Reprèn</translation>
    </message>
    <message>
        <source>Force Resume</source>
        <comment>Force Resume/start the torrent</comment>
        <translation>Força la represa</translation>
    </message>
    <message>
        <source>Pause</source>
        <comment>Pause the torrent</comment>
        <translation>Pausa</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>Delete the torrent</comment>
        <translation>Suprimeix</translation>
    </message>
    <message>
        <source>Limit share ratio...</source>
        <translation>Límit de ràtio de compartició...</translation>
    </message>
    <message>
        <source>Limit upload rate...</source>
        <translation>Limita la velocitat de pujada...</translation>
    </message>
    <message>
        <source>Limit download rate...</source>
        <translation>Limita la velocitat de baixada...</translation>
    </message>
    <message>
        <source>Move up</source>
        <comment>i.e. move up in the queue</comment>
        <translation>Moure amunt</translation>
    </message>
    <message>
        <source>Move down</source>
        <comment>i.e. Move down in the queue</comment>
        <translation>Moure avall</translation>
    </message>
    <message>
        <source>Move to top</source>
        <comment>i.e. Move to top of the queue</comment>
        <translation>Moure al principi</translation>
    </message>
    <message>
        <source>Move to bottom</source>
        <comment>i.e. Move to bottom of the queue</comment>
        <translation>Moure al final</translation>
    </message>
    <message>
        <source>Set location...</source>
        <translation>Estableix una destinació...</translation>
    </message>
    <message>
        <source>Copy name</source>
        <translation>Copia el nom</translation>
    </message>
    <message>
        <source>Copy hash</source>
        <translation>Copia'n l'etiqueta</translation>
    </message>
    <message>
        <source>Download first and last pieces first</source>
        <translation>Baixa primer el primer i l'últim tros.</translation>
    </message>
    <message>
        <source>Automatic Torrent Management</source>
        <translation>Gestió automàtica dels torrents</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Categoria</translation>
    </message>
    <message>
        <source>New...</source>
        <comment>New category...</comment>
        <translation>Nou...</translation>
    </message>
    <message>
        <source>Reset</source>
        <comment>Reset category</comment>
        <translation>Restableix</translation>
    </message>
    <message>
        <source>Priority</source>
        <translation>Prioritat</translation>
    </message>
    <message>
        <source>Force recheck</source>
        <translation>Força la verificació</translation>
    </message>
    <message>
        <source>Copy magnet link</source>
        <translation>Copia l'enllaç magnètic</translation>
    </message>
    <message>
        <source>Super seeding mode</source>
        <translation>Mode de supersembra</translation>
    </message>
    <message>
        <source>Rename...</source>
        <translation>Canvia el nom...</translation>
    </message>
    <message>
        <source>Download in sequential order</source>
        <translation>Baixa en ordre seqüencial</translation>
    </message>
    <message>
        <source>Force Recheck</source>
        <translation>Força la verificació</translation>
    </message>
    <message>
        <source>New Category</source>
        <translation>Categoria nova</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Ubicació</translation>
    </message>
    <message>
        <source>New name</source>
        <translation>Nom nou</translation>
    </message>
    <message>
        <source>Set location</source>
        <translation>Estableix la ubicació</translation>
    </message>
    <message>
        <source>Force reannounce</source>
        <translation>Força el reanunci</translation>
    </message>
    <message>
        <source>Edit Category</source>
        <translation>Edita la categoria</translation>
    </message>
    <message>
        <source>Save path</source>
        <translation>Camí per desar</translation>
    </message>
</context>
<context>
    <name>UpDownRatioDialog</name>
    <message>
        <source>Torrent Upload/Download Ratio Limiting</source>
        <translation>Limitació de ràtio de pujada / baixada</translation>
    </message>
    <message>
        <source>Use global share limit</source>
        <translation>Usa el límit de compartició global</translation>
    </message>
    <message>
        <source>Set no share limit</source>
        <translation>No estableixis límit de compartició</translation>
    </message>
    <message>
        <source>Set share limit to</source>
        <translation>Estableix el límit de compartició a</translation>
    </message>
    <message>
        <source>ratio</source>
        <translation>ràtio</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minuts</translation>
    </message>
</context>
<context>
    <name>about</name>
    <message>
        <source>An advanced BitTorrent client programmed in C++, based on Qt toolkit and libtorrent-rasterbar.</source>
        <translation>Un client BitTorrent avançat programat en C++, basat en el joc d'eines Qt i libtorrent-rasterbar.</translation>
    </message>
    <message>
        <source>Home Page:</source>
        <translation>Pàgina principal:</translation>
    </message>
    <message>
        <source>Forum:</source>
        <translation>Fòrum:</translation>
    </message>
    <message>
        <source>Bug Tracker:</source>
        <translation>Rastrejador d'errors:</translation>
    </message>
</context>
<context>
    <name>confirmDeletionDlg</name>
    <message>
        <source>Deletion confirmation</source>
        <translation>Confirmació de supressió</translation>
    </message>
    <message>
        <source>Also delete the files on the hard disk</source>
        <translation>Suprimeix també el fitxer del disc dur</translation>
    </message>
    <message>
        <source>Deletion confirmation - qBittorrent</source>
        <translation>Confirmació de supressió - qBittorrent</translation>
    </message>
</context>
<context>
    <name>downloadFromURL</name>
    <message>
        <source>Download from URLs</source>
        <translation>Baixa des d'URLs</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Baixa</translation>
    </message>
    <message>
        <source>Add Torrent Links</source>
        <translation>Afegeix un enllaços de torrent</translation>
    </message>
</context>
<context>
    <name>misc</name>
    <message>
        <source>B</source>
        <comment>bytes</comment>
        <translation>B</translation>
    </message>
    <message>
        <source>KiB</source>
        <comment>kibibytes (1024 bytes)</comment>
        <translation>KiB</translation>
    </message>
    <message>
        <source>MiB</source>
        <comment>mebibytes (1024 kibibytes)</comment>
        <translation>MiB</translation>
    </message>
    <message>
        <source>GiB</source>
        <comment>gibibytes (1024 mibibytes)</comment>
        <translation>GiB</translation>
    </message>
    <message>
        <source>TiB</source>
        <comment>tebibytes (1024 gibibytes)</comment>
        <translation>TiB</translation>
    </message>
    <message>
        <source>PiB</source>
        <comment>pebibytes (1024 tebibytes)</comment>
        <translation>PiB</translation>
    </message>
    <message>
        <source>EiB</source>
        <comment>exbibytes (1024 pebibytes)</comment>
        <translation>EiB</translation>
    </message>
    <message>
        <source>/s</source>
        <comment>per second</comment>
        <translation>/s</translation>
    </message>
    <message>
        <source>%1h %2m</source>
        <comment>e.g: 3hours 5minutes</comment>
        <translation>%1h %2m</translation>
    </message>
    <message>
        <source>%1d %2h</source>
        <comment>e.g: 2days 10hours</comment>
        <translation>%1d %2h</translation>
    </message>
    <message>
        <source>Unknown</source>
        <comment>Unknown (size)</comment>
        <translation>Desconegut</translation>
    </message>
    <message>
        <source>&lt; 1m</source>
        <comment>&lt; 1 minute</comment>
        <translation>&lt;1m</translation>
    </message>
    <message>
        <source>%1m</source>
        <comment>e.g: 10minutes</comment>
        <translation>%1m</translation>
    </message>
</context>
<context>
    <name>TorrentsController</name>
    <message>
        <source>Save path is empty</source>
        <translation>El camí per desar és buit</translation>
    </message>
</context>
<context>
    <name>PluginSourceDlg</name>
    <message>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <source>Plugin path:</source>
        <translation>Camí del connector:</translation>
    </message>
    <message>
        <source>URL or local directory</source>
        <translation>URL o directori local</translation>
    </message>
    <message>
        <source>Install plugin</source>
        <translation>Instal·la el connector</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>D'acord</translation>
    </message>
</context>
<context>
    <name>SearchEngineWidget</name>
    <message>
        <source>Seeds:</source>
        <translation>Llavors:</translation>
    </message>
    <message>
        <source>All plugins</source>
        <translation>Tots els connectors</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Mida:</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Atura</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Cerca</translation>
    </message>
    <message>
        <source>Search plugins...</source>
        <translation>Cerca connectors...</translation>
    </message>
    <message>
        <source>All categories</source>
        <translation>Totes les categories</translation>
    </message>
    <message>
        <source>Search in:</source>
        <translation>Cerca a:</translation>
    </message>
    <message>
        <source>Copy description page URL</source>
        <translation>Copia l'URL de la pàgina de descripció</translation>
    </message>
    <message>
        <source>Go to description page</source>
        <translation>Ves a la pàgina de descripció</translation>
    </message>
    <message>
        <source>Results (showing</source>
        <translation>Resultats</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Baixa</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Filtre</translation>
    </message>
    <message>
        <source>Torrent names only</source>
        <translation>Només els noms de torrents</translation>
    </message>
    <message>
        <source>Only enabled</source>
        <translation>Només habilitat</translation>
    </message>
    <message>
        <source>out of</source>
        <translation>fora de</translation>
    </message>
    <message>
        <source>Everywhere</source>
        <translation>Arreu</translation>
    </message>
</context>
<context>
    <name>PluginSelectDlg</name>
    <message>
        <source>Uninstall</source>
        <translation>Desinstal·la</translation>
    </message>
    <message>
        <source>Install new plugin</source>
        <translation>Instal·la el connector nou</translation>
    </message>
    <message>
        <source>You can get new search engine plugins here:</source>
        <translation>Podeu obtenir connectors de cerca nous aquí:</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Tanca</translation>
    </message>
    <message>
        <source>Installed search plugins:</source>
        <translation>Connectors de cerca instal·lats:</translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation>Habilitat</translation>
    </message>
    <message>
        <source>Warning: Be sure to comply with your country's copyright laws when downloading torrents from any of these search engines.</source>
        <translation>Avís: assegureu-vos que compliu les lleis de dret de còpia del vostre país quan baixeu torrents des de qualsevol d'aquests motors de cerca.</translation>
    </message>
    <message>
        <source>Check for updates</source>
        <translation>Comprova si hi ha actualitzacions</translation>
    </message>
    <message>
        <source>Search plugins</source>
        <translation>Connectors de cerca</translation>
    </message>
</context>
<context>
    <name>SearchResultsTable</name>
    <message>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Mida</translation>
    </message>
    <message>
        <source>Leechers</source>
        <translation>Sangoneres</translation>
    </message>
    <message>
        <source>Search engine</source>
        <translation>Motor de cerca</translation>
    </message>
    <message>
        <source>Seeders</source>
        <translation>Sembradors</translation>
    </message>
</context>
<context>
    <name>SearchPluginsTable</name>
    <message>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <source>Url</source>
        <translation>URL</translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation>Habilitat</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versió</translation>
    </message>
</context>
</TS>